@@ -7,7 +7,7 @@ use Moose;
 use namespace::autoclean;
 use Method::Signatures;
 use Data::Printer alias => 'pdump';
-use MySQL::Util::Lite::ForeignKeyColumn;
+use MySQL::Util::Lite::ColumnConstraint;
 
 has name => (
 	is       => 'ro',
@@ -15,19 +15,25 @@ has name => (
 	required => 1,
 );
 
-has schema_name => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 1,
+has column_constraints => (
+	is => 'rw',
+	isa => 'ArrayRef[MySQL::Util::Lite::ColumnConstraint]',
+	lazy => 1,
+	builder => '_build_column_constraints',	
 );
 
 has _util => (
-	is       => 'ro',
-	isa      => 'MySQL::Util',
+	is => 'ro',
+	isa => 'MySQL::Util',
 	required => 1,
 );
 
-method get_columns {
+method get_column_constraints {
+
+	return @{ $self->column_constraints };	
+}
+
+method _build_column_constraints {
 
 	my $aref = $self->_util->get_constraint(
 		name  => $self->name
@@ -36,8 +42,8 @@ method get_columns {
 	my @cols;
 
 	foreach my $col (@$aref) {
-		push @cols, MySQL::Util::Lite::ForeignKeyColumn->new(
-			name        => $col->{COLUMN_NAME},
+		push @cols, MySQL::Util::Lite::ColumnConstraint->new(
+			column_name => $col->{COLUMN_NAME},
 			table_name  => $col->{TABLE_NAME},
 			schema_name => $col->{CONSTRAINT_SCHEMA},
 			parent_column_name => $col->{REFERENCED_COLUMN_NAME},
@@ -47,7 +53,7 @@ method get_columns {
 
 	}
 
-	return @cols;
+	return \@cols;
 }
 
 1;
